@@ -237,6 +237,7 @@ class Spec:
         idl.markupIDL(self)
         inlineRemoteIssues(self)
         wpt.processWptElements(self)
+        addImageSize(self)
 
         # Handle all the links
         processBiblioLinks(self)
@@ -545,9 +546,9 @@ styleColors = """
     --ins-bg: transparent;
 
     --a-normal-text: #034575;
-    --a-normal-underline: #707070;
+    --a-normal-underline: #bbb;
     --a-visited-text: var(--a-normal-text);
-    --a-visited-underline: #bbb;
+    --a-visited-underline: #707070;
     --a-hover-bg: rgba(75%, 75%, 75%, .25);
     --a-active-text: #c00;
     --a-active-underline: #c00;
