@@ -126,6 +126,7 @@ class MetadataManager:
         self.workStatus = None
         self.wptDisplay = "none"
         self.wptPathPrefix = None
+        self.imgAutoSize = True
 
         self.otherMetadata = DefaultOrderedDict(list)
 
@@ -273,10 +274,12 @@ class MetadataManager:
             macros["longstatus"] = config.shortToLongStatus[self.status]
         else:
             macros["longstatus"] = ""
-        if self.status in ("w3c/LCWD", "w3c/FPWD"):
+        if self.status in ("w3c/LCWD", "w3c/FPWD", "w3c/NOTE-FPWD"):
             macros["status"] = "WD"
         elif self.status in ("w3c/WG-NOTE", "w3c/IG-NOTE"):
             macros["status"] = "NOTE"
+        elif self.status == "w3c/NOTE-ED":
+            macros["status"] = "ED"
         else:
             macros["status"] = self.rawStatus
         if self.workStatus:
@@ -338,7 +341,7 @@ class MetadataManager:
             macros["mailinglist"] = self.mailingList
         if self.mailingListArchives:
             macros["mailinglistarchives"] = self.mailingListArchives
-        if self.status == "w3c/FPWD":
+        if self.status in ("w3c/FPWD", "w3c/NOTE-FPWD", "w3c/NOTE-WD"):
             macros[
                 "w3c-stylesheet-url"
             ] = "https://www.w3.org/StyleSheets/TR/2016/W3C-WD"
@@ -354,6 +357,10 @@ class MetadataManager:
             macros[
                 "w3c-stylesheet-url"
             ] = "https://www.w3.org/StyleSheets/TR/2016/cg-final"
+        elif self.status == "w3c/NOTE-ED":
+            macros[
+                "w3c-stylesheet-url"
+            ] = "https://www.w3.org/StyleSheets/TR/2016/W3C-ED"
         else:
             shortStatus = (
                 self.rawStatus.partition("/")[2]
@@ -1022,10 +1029,10 @@ def parseMetadataOrder(key, val, lineNum):  # pylint: disable=unused-argument
 
 def parseWptDisplay(key, val, lineNum):  # pylint: disable=unused-argument
     val = val.lower()
-    if val in ("none", "inline"):
+    if val in ("none", "inline", "open", "closed"):
         return val
     die(
-        "WPT Display metadata only accepts the values 'none' or 'inline'. Got '{0}'.",
+        "WPT Display metadata only accepts the values 'none', 'closed', 'open', or 'inline'. Got '{0}'.",
         val,
         lineNum=lineNum,
     )
@@ -1348,6 +1355,9 @@ knownKeys = {
     "Ignored Vars": Metadata(
         "Ignored Vars", "ignoredVars", joinList, parseCommaSeparated
     ),
+    "Image Auto Size": Metadata(
+        "Image Auto Size", "imgAutoSize", joinValue, parseBoolean
+    ),
     "Implementation Report": Metadata(
         "Implementation Report", "implementationReport", joinValue, parseLiteral
     ),
